summaryrefslogtreecommitdiffstats
path: root/chrome/installer/setup
diff options
context:
space:
mode:
authorerikwright@chromium.org <erikwright@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-07 22:44:41 +0000
committererikwright@chromium.org <erikwright@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-11-07 22:44:41 +0000
commitb6ac6df43087539e867d4ae3666ef8bb032846c1 (patch)
treee0897640ee0167b26baa049baa4c205fbf587222 /chrome/installer/setup
parent2b2273f385daa81166c938ba5c1cde76caeaf629 (diff)
downloadchromium_src-b6ac6df43087539e867d4ae3666ef8bb032846c1.zip
chromium_src-b6ac6df43087539e867d4ae3666ef8bb032846c1.tar.gz
chromium_src-b6ac6df43087539e867d4ae3666ef8bb032846c1.tar.bz2
Modify the App Host quick enable app command to install the launcher.
R=huangs,gab BUG=151626 TEST=Verify that the App Host quick-enable command has --app-launcher, not --app-host. Review URL: https://chromiumcodereview.appspot.com/11362133 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@166536 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/installer/setup')
-rw-r--r--chrome/installer/setup/install_worker.cc12
-rw-r--r--chrome/installer/setup/install_worker.h2
-rw-r--r--chrome/installer/setup/uninstall.cc6
3 files changed, 10 insertions, 10 deletions
diff --git a/chrome/installer/setup/install_worker.h b/chrome/installer/setup/install_worker.h
index 3a64d1e..a303b28 100644
--- a/chrome/installer/setup/install_worker.h
+++ b/chrome/installer/setup/install_worker.h
@@ -198,7 +198,7 @@ void AddQuickEnableChromeFrameWorkItems(const InstallerState& installer_state,
// product(s) currently being installed) are required when processing product
// installation; they are unused ((and may therefore be empty) when
// uninstalling).
-void AddQuickEnableApplicationHostWorkItems(
+void AddQuickEnableApplicationLauncherWorkItems(
const InstallerState& installer_state,
const InstallationState& machine_state,
const FilePath& setup_path,
diff --git a/chrome/installer/setup/uninstall.cc b/chrome/installer/setup/uninstall.cc
index d670288..0dcafee 100644
--- a/chrome/installer/setup/uninstall.cc
+++ b/chrome/installer/setup/uninstall.cc
@@ -150,9 +150,9 @@ void ProcessQuickEnableWorkItems(
AddQuickEnableChromeFrameWorkItems(installer_state, machine_state, FilePath(),
Version(), work_item_list.get());
- AddQuickEnableApplicationHostWorkItems(installer_state, machine_state,
- FilePath(), Version(),
- work_item_list.get());
+ AddQuickEnableApplicationLauncherWorkItems(installer_state, machine_state,
+ FilePath(), Version(),
+ work_item_list.get());
if (!work_item_list->Do())
LOG(ERROR) << "Failed to update quick-enable-cf command.";
}
diff --git a/chrome/installer/setup/install_worker.cc b/chrome/installer/setup/install_worker.cc
index f23736c..3929d07 100644
--- a/chrome/installer/setup/install_worker.cc
+++ b/chrome/installer/setup/install_worker.cc
@@ -1114,9 +1114,9 @@ void AddInstallWorkItems(const InstallationState& original_state,
// Copy over brand, usagestats, and other values.
AddGoogleUpdateWorkItems(original_state, installer_state, install_list);
- AddQuickEnableApplicationHostWorkItems(installer_state, original_state,
- setup_path, new_version,
- install_list);
+ AddQuickEnableApplicationLauncherWorkItems(installer_state, original_state,
+ setup_path, new_version,
+ install_list);
AddQuickEnableChromeFrameWorkItems(installer_state, original_state,
setup_path, new_version, install_list);
@@ -1553,7 +1553,7 @@ void AddQuickEnableChromeFrameWorkItems(const InstallerState& installer_state,
work_item_list);
}
-void AddQuickEnableApplicationHostWorkItems(
+void AddQuickEnableApplicationLauncherWorkItems(
const InstallerState& installer_state,
const InstallationState& machine_state,
const FilePath& setup_path,
@@ -1563,11 +1563,11 @@ void AddQuickEnableApplicationHostWorkItems(
CommandLine cmd_line(CommandLine::NO_PROGRAM);
cmd_line.AppendSwitch(switches::kMultiInstall);
- cmd_line.AppendSwitch(switches::kChromeAppHost);
+ cmd_line.AppendSwitch(switches::kChromeAppLauncher);
cmd_line.AppendSwitch(switches::kEnsureGoogleUpdatePresent);
// For system-level binaries there is no way to keep the command state in sync
// with the installation/uninstallation of the Application Host (which is
// always at user-level).
// So we pass false for 'have_child_product' to cause this command to always
// be installed if the Chrome Binaries are installed.
@@ -1563,11 +1563,11 @@ void AddQuickEnableApplicationHostWorkItems(
cmd_line.AppendSwitch(switches::kEnsureGoogleUpdatePresent);
// For system-level binaries there is no way to keep the command state in sync
- // with the installation/uninstallation of the Application Host (which is
+ // with the installation/uninstallation of the Application Launcher (which is
// always at user-level).
// So we pass false for 'have_child_product' to cause this command to always